/*
 ***********************************************************************************************************************
 *
 * Copyright (c) 2022-2023, Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** JO           Julia Ott                                                     **
** CK           Chander Kumar                                                 **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2022-08-25, JO, CK: EP-1243: Initial version of application        **
** V1.1.0: 2023-04-18, JO:     EP-1235: Changed to C startup file             **
** V1.2.0: 2024-06-14, JO:     EP-1480: Disabled warning 'unsafe buffer usage'**
**                             (ARM compiler for Embedded version >6.21)      **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** Application example                                                        **
********************************************************************************
** Flash both Bootloader and Application example to the chip.                 **
** Bootloader toggels P0.1.                                                   **
** On MON1 press, the Bootloader jumps to the application (P0.1 not toggled   **
** anymore).                                                                  **
** Application toggels P0.2.                                                  **
*******************************************************************************/

/*******************************************************************************
**                                  Includes                                  **
*******************************************************************************/
#include "tle_device.h"
#include "types.h"
#include "gpio.h"

/*******************************************************************************
**                           Function Declarations                            **
*******************************************************************************/
void MON2_RI_Int(void);


sint32 main(void)
{
  sint8 s8_returnCode;
  uint32 u32_tick = 0;
  
  /* Enable all interrupts that are disbaled by BL before jump to application */
  __enable_irq();
  
   /* Main watchdog service */
   /* Service watchdog by toggling bit PMU->WD_TRIG.bit.TRIG to close the SOW opened in the BL */
   PMU->WD_TRIG.bit.TRIG ^= 1u;

  /* Initialization of hardware modules based on Config Wizard configuration */
  s8_returnCode = TLE_init();
  
  if (s8_returnCode != ERR_LOG_SUCCESS)
  {
    /* Place your code here to handle an initialization error */
  }

  for (;;)
  {
    /* Main watchdog service */
    (void) PMU_serviceFailSafeWatchdog();

    u32_tick++;
    if (u32_tick > 100000)
    {
      GPIO_setP02State(GPIO_STATE_TOGGLE);
      u32_tick = 0;
    }
  }
}


/* user-defined call back function for rising edge on MON2 pin */
__attribute__((__noreturn__))void MON2_RI_Int(void)
{
  /* Reset device to start execution from bootloader again */
  __NVIC_SystemReset();
}
