/**************************************************************************************************
*                _  _               ___             _                                             *
*               (_)| |__   _ __    / _ \ _ __ ___  | |__    /\  /\                                *
*               | || '_ \ | '__|  / /_\/| '_ ` _ \ | '_ \  / /_/ /                                *
*               | || | | || |    / /_\\ | | | | | || |_) |/ __  /                                 *
*               |_||_| |_||_|    \____/ |_| |_| |_||_.__/ \/ /_/                                  *
*                                                                                                 *
*    ihr GmbH                                                                                     *
*    Airport Boulevard B210                                                                       *
*    77836 Rheinmuenster - Germany                                                                *
*    http://www.ihr.de                                                                            *
*    Phone +49(0) 7229-18475-0                                                                    *
*    Fax   +49(0) 7229-18475-11                                                                   *
*                                                                                                 *
**************************************************************************************************/
/**
@file         com_cfg.c
@brief        CAN driver configuration
*/
#include "com_types.h"

/* Tx message buffers */
static uint8 CanTx_Buffer_DemoTxClassicMsg[8u];
static uint8 CanTx_Buffer_DemoTxFdMsg[64u];

/* Rx message buffers */
static uint8 CanRx_Buffer_DemoRxClassicMsg[8u];
static uint8 CanRx_Buffer_DemoRxFdMsg[64u];

/* Initial values for Tx message buffers */
static const uint8 CanTx_Init_DemoTxClassicMsg[8u] = {0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u};
static const uint8 CanTx_Init_DemoTxFdMsg[64u] = {0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u};

/* Initial values for Rx message buffers */
static const uint8 CanRx_Init_DemoRxClassicMsg[8u] = {0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u};
static const uint8 CanRx_Init_DemoRxFdMsg[64u] = {0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u,0x00u};

static const stComFrameDescriptor CanTx_FrameList[2u] = 
{   
   /* Message: DemoTxClassicMsg  */
   {
      .Handle        = 0u,
      .Id            = 0x234u,
      .BufferSize    = 8u,
      .Flags         = 0x00u, /* Possible settings: FLAGS_FD_FRAME | FLAGS_USE_BRS | FLAGS_EXT_ID */
      .Channel       = 0u,
      .pBuffer       = CanTx_Buffer_DemoTxClassicMsg,
      .pShadow       = NULL,
      .pInitData     = CanTx_Init_DemoTxClassicMsg,
      .CalloutFunc   = NULL,  /* This feature is not available in the demo version. */
      .ErrorFunc     = NULL,  /* This feature is not available in the demo version. */
      .FirstSignal   = 0u,
      .NSignals      = 4u,
      .CycleTO       = 20u,   /* Configure the Tx cycle in ms here. Write 0 to disable cyclic transmission. */
   },
   
   /* Message: DemoTxFdMsg  */
   {
      .Handle        = 1u,
      .Id            = 0x234567u,
      .BufferSize    = 64u,
      .Flags         = (FLAGS_FD_FRAME | FLAGS_USE_BRS | FLAGS_EXT_ID), /* Possible settings: FLAGS_FD_FRAME | FLAGS_USE_BRS | FLAGS_EXT_ID */
      .Channel       = 0u,
      .pBuffer       = CanTx_Buffer_DemoTxFdMsg,
      .pShadow       = NULL,
      .pInitData     = CanTx_Init_DemoTxFdMsg,
      .CalloutFunc   = NULL,  /* This feature is not available in the demo version. */
      .ErrorFunc     = NULL,  /* This feature is not available in the demo version. */
      .FirstSignal   = 4u,
      .NSignals      = 26u,
      /* Note: The optional CAN-FD frame's cyclic transmission can be enabled here. Write i.e. 
         .CycleTO = 20u to enable a transmission cycle of 20 ms. */
      .CycleTO       = 0u,    /* Configure the Tx cycle in ms here. Write 0 to disable cyclic transmission. */
   }
};
static const stComFrameDescriptor CanRx_FrameList[2u] = 
{   
   /* Message: DemoRxClassicMsg  */
   {
      .Handle        = 0u,
      .Id            = 0x123u,
      .BufferSize    = 8u,
      .Flags         = 0x00u,  /* Possible settings: FLAGS_FD_FRAME | FLAGS_USE_BRS | FLAGS_EXT_ID */
      .Channel       = 0u,
      .pBuffer       = CanRx_Buffer_DemoRxClassicMsg,
      .pShadow       = NULL,
      .pInitData     = CanRx_Init_DemoRxClassicMsg,
      .CalloutFunc   = NULL,  /* This feature is not available in the demo version. */
      .ErrorFunc     = NULL,  /* This feature is not available in the demo version. */
      .FirstSignal   = 0u,
      .NSignals      = 4u,
      .CycleTO       = 0u,
   },
   
   /* Message: DemoRxFdMsg  */
   {
      .Handle        = 1u,
      .Id            = 0x123456u,
      .BufferSize    = 64u,
      .Flags         = (FLAGS_FD_FRAME | FLAGS_USE_BRS | FLAGS_EXT_ID), /* Possible settings: FLAGS_FD_FRAME | FLAGS_USE_BRS | FLAGS_EXT_ID */
      .Channel       = 0u,
      .pBuffer       = CanRx_Buffer_DemoRxFdMsg,
      .pShadow       = NULL,
      .pInitData     = CanRx_Init_DemoRxFdMsg,
      .CalloutFunc   = NULL,
      .ErrorFunc     = NULL,
      .FirstSignal   = 4u,
      .NSignals      = 26u,
      .CycleTO       = 0u,
   }
};
static const stComSignalDescriptor Can_TxSignalList[30u] = 
{
   
   {
      .Handle  = 0u,
      .Owner   = 0u,
      .BitPos  = 8u,
      .BitSize = 8u,
      .Format  = 0x08u,
   },
   
   {
      .Handle  = 1u,
      .Owner   = 0u,
      .BitPos  = 0u,
      .BitSize = 8u,
      .Format  = 0x08u,
   },
   
   {
      .Handle  = 2u,
      .Owner   = 0u,
      .BitPos  = 16u,
      .BitSize = 16u,
      .Format  = 0x09u,
   },
   
   {
      .Handle  = 3u,
      .Owner   = 0u,
      .BitPos  = 32u,
      .BitSize = 32u,
      .Format  = 0x0Au,
   },
   
   {
      .Handle  = 4u,
      .Owner   = 1u,
      .BitPos  = 56u,
      .BitSize = 8u,
      .Format  = 0x08u,
   },
   
   {
      .Handle  = 5u,
      .Owner   = 1u,
      .BitPos  = 48u,
      .BitSize = 8u,
      .Format  = 0x08u,
   },
   
   {
      .Handle  = 6u,
      .Owner   = 1u,
      .BitPos  = 40u,
      .BitSize = 8u,
      .Format  = 0x08u,
   },
   
   {
      .Handle  = 7u,
      .Owner   = 1u,
      .BitPos  = 32u,
      .BitSize = 8u,
      .Format  = 0x08u,
   },
   
   {
      .Handle  = 8u,
      .Owner   = 1u,
      .BitPos  = 24u,
      .BitSize = 8u,
      .Format  = 0x08u,
   },
   
   {
      .Handle  = 9u,
      .Owner   = 1u,
      .BitPos  = 16u,
      .BitSize = 8u,
      .Format  = 0x08u,
   },
   
   {
      .Handle  = 10u,
      .Owner   = 1u,
      .BitPos  = 8u,
      .BitSize = 8u,
      .Format  = 0x08u,
   },
   
   {
      .Handle  = 11u,
      .Owner   = 1u,
      .BitPos  = 0u,
      .BitSize = 8u,
      .Format  = 0x08u,
   },
   
   {
      .Handle  = 12u,
      .Owner   = 1u,
      .BitPos  = 176u,
      .BitSize = 16u,
      .Format  = 0x09u,
   },
   
   {
      .Handle  = 13u,
      .Owner   = 1u,
      .BitPos  = 160u,
      .BitSize = 16u,
      .Format  = 0x09u,
   },
   
   {
      .Handle  = 14u,
      .Owner   = 1u,
      .BitPos  = 144u,
      .BitSize = 16u,
      .Format  = 0x09u,
   },
   
   {
      .Handle  = 15u,
      .Owner   = 1u,
      .BitPos  = 128u,
      .BitSize = 16u,
      .Format  = 0x09u,
   },
   
   {
      .Handle  = 16u,
      .Owner   = 1u,
      .BitPos  = 112u,
      .BitSize = 16u,
      .Format  = 0x09u,
   },
   
   {
      .Handle  = 17u,
      .Owner   = 1u,
      .BitPos  = 96u,
      .BitSize = 16u,
      .Format  = 0x09u,
   },
   
   {
      .Handle  = 18u,
      .Owner   = 1u,
      .BitPos  = 80u,
      .BitSize = 16u,
      .Format  = 0x09u,
   },
   
   {
      .Handle  = 19u,
      .Owner   = 1u,
      .BitPos  = 64u,
      .BitSize = 16u,
      .Format  = 0x09u,
   },
   
   {
      .Handle  = 20u,
      .Owner   = 1u,
      .BitPos  = 480u,
      .BitSize = 32u,
      .Format  = 0x0Au,
   },
   
   {
      .Handle  = 21u,
      .Owner   = 1u,
      .BitPos  = 448u,
      .BitSize = 32u,
      .Format  = 0x0Au,
   },
   
   {
      .Handle  = 22u,
      .Owner   = 1u,
      .BitPos  = 416u,
      .BitSize = 32u,
      .Format  = 0x0Au,
   },
   
   {
      .Handle  = 23u,
      .Owner   = 1u,
      .BitPos  = 384u,
      .BitSize = 32u,
      .Format  = 0x0Au,
   },
   
   {
      .Handle  = 24u,
      .Owner   = 1u,
      .BitPos  = 352u,
      .BitSize = 32u,
      .Format  = 0x0Au,
   },
   
   {
      .Handle  = 25u,
      .Owner   = 1u,
      .BitPos  = 320u,
      .BitSize = 32u,
      .Format  = 0x0Au,
   },
   
   {
      .Handle  = 26u,
      .Owner   = 1u,
      .BitPos  = 288u,
      .BitSize = 32u,
      .Format  = 0x0Au,
   },
   
   {
      .Handle  = 27u,
      .Owner   = 1u,
      .BitPos  = 256u,
      .BitSize = 32u,
      .Format  = 0x0Au,
   },
   
   {
      .Handle  = 28u,
      .Owner   = 1u,
      .BitPos  = 224u,
      .BitSize = 32u,
      .Format  = 0x0Au,
   },
   
   {
      .Handle  = 29u,
      .Owner   = 1u,
      .BitPos  = 192u,
      .BitSize = 32u,
      .Format  = 0x0Au,
   }
};
static const stComSignalDescriptor Can_RxSignalList[30u] = 
{
   
   {
      .Handle  = 0u,
      .Owner   = 0u,
      .BitPos  = 8u,
      .BitSize = 8u,
      .Format  = 0x08u,
   },
   
   {
      .Handle  = 1u,
      .Owner   = 0u,
      .BitPos  = 0u,
      .BitSize = 8u,
      .Format  = 0x08u,
   },
   
   {
      .Handle  = 2u,
      .Owner   = 0u,
      .BitPos  = 16u,
      .BitSize = 16u,
      .Format  = 0x09u,
   },
   
   {
      .Handle  = 3u,
      .Owner   = 0u,
      .BitPos  = 32u,
      .BitSize = 32u,
      .Format  = 0x0Au,
   },
   
   {
      .Handle  = 4u,
      .Owner   = 1u,
      .BitPos  = 56u,
      .BitSize = 8u,
      .Format  = 0x08u,
   },
   
   {
      .Handle  = 5u,
      .Owner   = 1u,
      .BitPos  = 48u,
      .BitSize = 8u,
      .Format  = 0x08u,
   },
   
   {
      .Handle  = 6u,
      .Owner   = 1u,
      .BitPos  = 40u,
      .BitSize = 8u,
      .Format  = 0x08u,
   },
   
   {
      .Handle  = 7u,
      .Owner   = 1u,
      .BitPos  = 32u,
      .BitSize = 8u,
      .Format  = 0x08u,
   },
   
   {
      .Handle  = 8u,
      .Owner   = 1u,
      .BitPos  = 24u,
      .BitSize = 8u,
      .Format  = 0x08u,
   },
   
   {
      .Handle  = 9u,
      .Owner   = 1u,
      .BitPos  = 16u,
      .BitSize = 8u,
      .Format  = 0x08u,
   },
   
   {
      .Handle  = 10u,
      .Owner   = 1u,
      .BitPos  = 8u,
      .BitSize = 8u,
      .Format  = 0x08u,
   },
   
   {
      .Handle  = 11u,
      .Owner   = 1u,
      .BitPos  = 0u,
      .BitSize = 8u,
      .Format  = 0x08u,
   },
   
   {
      .Handle  = 12u,
      .Owner   = 1u,
      .BitPos  = 176u,
      .BitSize = 16u,
      .Format  = 0x09u,
   },
   
   {
      .Handle  = 13u,
      .Owner   = 1u,
      .BitPos  = 160u,
      .BitSize = 16u,
      .Format  = 0x09u,
   },
   
   {
      .Handle  = 14u,
      .Owner   = 1u,
      .BitPos  = 144u,
      .BitSize = 16u,
      .Format  = 0x09u,
   },
   
   {
      .Handle  = 15u,
      .Owner   = 1u,
      .BitPos  = 128u,
      .BitSize = 16u,
      .Format  = 0x09u,
   },
   
   {
      .Handle  = 16u,
      .Owner   = 1u,
      .BitPos  = 112u,
      .BitSize = 16u,
      .Format  = 0x09u,
   },
   
   {
      .Handle  = 17u,
      .Owner   = 1u,
      .BitPos  = 96u,
      .BitSize = 16u,
      .Format  = 0x09u,
   },
   
   {
      .Handle  = 18u,
      .Owner   = 1u,
      .BitPos  = 80u,
      .BitSize = 16u,
      .Format  = 0x09u,
   },
   
   {
      .Handle  = 19u,
      .Owner   = 1u,
      .BitPos  = 64u,
      .BitSize = 16u,
      .Format  = 0x09u,
   },
   
   {
      .Handle  = 20u,
      .Owner   = 1u,
      .BitPos  = 480u,
      .BitSize = 32u,
      .Format  = 0x0Au,
   },
   
   {
      .Handle  = 21u,
      .Owner   = 1u,
      .BitPos  = 448u,
      .BitSize = 32u,
      .Format  = 0x0Au,
   },
   
   {
      .Handle  = 22u,
      .Owner   = 1u,
      .BitPos  = 416u,
      .BitSize = 32u,
      .Format  = 0x0Au,
   },
   
   {
      .Handle  = 23u,
      .Owner   = 1u,
      .BitPos  = 384u,
      .BitSize = 32u,
      .Format  = 0x0Au,
   },
   
   {
      .Handle  = 24u,
      .Owner   = 1u,
      .BitPos  = 352u,
      .BitSize = 32u,
      .Format  = 0x0Au,
   },
   
   {
      .Handle  = 25u,
      .Owner   = 1u,
      .BitPos  = 320u,
      .BitSize = 32u,
      .Format  = 0x0Au,
   },
   
   {
      .Handle  = 26u,
      .Owner   = 1u,
      .BitPos  = 288u,
      .BitSize = 32u,
      .Format  = 0x0Au,
   },
   
   {
      .Handle  = 27u,
      .Owner   = 1u,
      .BitPos  = 256u,
      .BitSize = 32u,
      .Format  = 0x0Au,
   },
   
   {
      .Handle  = 28u,
      .Owner   = 1u,
      .BitPos  = 224u,
      .BitSize = 32u,
      .Format  = 0x0Au,
   },
   
   {
      .Handle  = 29u,
      .Owner   = 1u,
      .BitPos  = 192u,
      .BitSize = 32u,
      .Format  = 0x0Au,
   }
};

const stComFrameDescriptor* COM_GetPtr_TxFrmDescrStart(void)
{
   return CanTx_FrameList;
}

const stComFrameDescriptor* COM_GetPtr_RxFrmDescrStart(void)
{
   return CanRx_FrameList;
}

const stComSignalDescriptor* COM_GetPtr_TxSignalsStart(void)
{
   return Can_TxSignalList;
}
const stComSignalDescriptor* COM_GetPtr_RxSignalsStart(void)
{
   return Can_RxSignalList;
}
