/**************************************************************************************************
*                _  _               ___             _                                             *
*               (_)| |__   _ __    / _ \ _ __ ___  | |__    /\  /\                                *
*               | || '_ \ | '__|  / /_\/| '_ ` _ \ | '_ \  / /_/ /                                *
*               | || | | || |    / /_\\ | | | | | || |_) |/ __  /                                 *
*               |_||_| |_||_|    \____/ |_| |_| |_||_.__/ \/ /_/                                  *
*                                                                                                 *
*    ihr GmbH                                                                                     *
*    Airport Boulevard B210                                                                       *
*    77836 Rheinmuenster - Germany                                                                *
*    http://www.ihr.de                                                                            *
*    Phone +49(0) 7229-18475-0                                                                    *
*    Fax   +49(0) 7229-18475-11                                                                   *
*                                                                                                 *
**************************************************************************************************/
/**
@file         com_cfg.h
@brief        Header file for CAN driver configuration
*/
#ifndef COM_CFG_H
#define COM_CFG_H

#include "types.h"

/* This feature is locked in the demo version. */
#define CAN_USE_LONG_ID STD_ON  /* Configuration contains extended IDs */

/* Tx message handles */
#define CanTx_DemoTxClassicMsg  0u 
#define CanTx_DemoTxFdMsg  1u 
 
/* Rx message handles */
#define CanRx_DemoRxClassicMsg  0u 
#define CanRx_DemoRxFdMsg  1u 

/* This feature is locked in the demo version. */
#define CAN_N_TX_FRAMES 2u 
#define CAN_N_RX_FRAMES 2u 

/* Tx signal handles */
#define CanTxSig_0_Cl_u8_2 0u 
#define CanTxSig_1_Cl_u8_1 1u 
#define CanTxSig_2_Cl_u16_1 2u 
#define CanTxSig_3_Cl_u32_1 3u 
#define CanTxSig_4_Fd_u8_8 4u 
#define CanTxSig_5_Fd_u8_7 5u 
#define CanTxSig_6_Fd_u8_6 6u 
#define CanTxSig_7_Fd_u8_5 7u 
#define CanTxSig_8_Fd_u8_4 8u 
#define CanTxSig_9_Fd_u8_3 9u 
#define CanTxSig_10_Fd_u8_2 10u 
#define CanTxSig_11_Fd_u8_1 11u 
#define CanTxSig_12_Fd_u16_8 12u 
#define CanTxSig_13_Fd_u16_7 13u 
#define CanTxSig_14_Fd_u16_6 14u 
#define CanTxSig_15_Fd_u16_5 15u 
#define CanTxSig_16_Fd_u16_4 16u 
#define CanTxSig_17_Fd_u16_3 17u 
#define CanTxSig_18_Fd_u16_2 18u 
#define CanTxSig_19_Fd_u16_1 19u 
#define CanTxSig_20_Fd_u32_10 20u 
#define CanTxSig_21_Fd_u32_09 21u 
#define CanTxSig_22_Fd_u32_08 22u 
#define CanTxSig_23_Fd_u32_07 23u 
#define CanTxSig_24_Fd_u32_06 24u 
#define CanTxSig_25_Fd_u32_05 25u 
#define CanTxSig_26_Fd_u32_04 26u 
#define CanTxSig_27_Fd_u32_03 27u 
#define CanTxSig_28_Fd_u32_02 28u 
#define CanTxSig_29_Fd_u32_01 29u 

/* Rx signal handles */
#define CanRxSig_0_Cl_u8_2 0u 
#define CanRxSig_1_Cl_u8_1 1u 
#define CanRxSig_2_Cl_u16_1 2u 
#define CanRxSig_3_Cl_u32_1 3u 
#define CanRxSig_4_Fd_u8_8 4u 
#define CanRxSig_5_Fd_u8_7 5u 
#define CanRxSig_6_Fd_u8_6 6u 
#define CanRxSig_7_Fd_u8_5 7u 
#define CanRxSig_8_Fd_u8_4 8u 
#define CanRxSig_9_Fd_u8_3 9u 
#define CanRxSig_10_Fd_u8_2 10u 
#define CanRxSig_11_Fd_u8_1 11u 
#define CanRxSig_12_Fd_u16_8 12u 
#define CanRxSig_13_Fd_u16_7 13u 
#define CanRxSig_14_Fd_u16_6 14u 
#define CanRxSig_15_Fd_u16_5 15u 
#define CanRxSig_16_Fd_u16_4 16u 
#define CanRxSig_17_Fd_u16_3 17u 
#define CanRxSig_18_Fd_u16_2 18u 
#define CanRxSig_19_Fd_u16_1 19u 
#define CanRxSig_20_Fd_u32_10 20u 
#define CanRxSig_21_Fd_u32_09 21u 
#define CanRxSig_22_Fd_u32_08 22u 
#define CanRxSig_23_Fd_u32_07 23u 
#define CanRxSig_24_Fd_u32_06 24u 
#define CanRxSig_25_Fd_u32_05 25u 
#define CanRxSig_26_Fd_u32_04 26u 
#define CanRxSig_27_Fd_u32_03 27u 
#define CanRxSig_28_Fd_u32_02 28u 
#define CanRxSig_29_Fd_u32_01 29u 

/* This feature is locked in the demo version. */
#define CAN_N_TX_SIGNALS 30u 
#define CAN_N_RX_SIGNALS 30u 

#endif /*#ifndef COM_CFG_H */
