#<checksum>f2c10b5d988f458e0049229e7069031e1ff5407527bc39bed0a301909c9d9c46</checksum>

#
# \file     graph_phases.py
#
# \brief    python script update the graph with the phases according to XML settings
#
# \version  V1.0.0
# \date     15 May 2021
#

###############################################################################
#                              Author(s) Identity                             #
#*****************************************************************************#
#  Initials     Name                                                          #
#  -------------------------------------------------------------------------- #
#  JO           Julia Ott                                                     #
###############################################################################

###############################################################################
#                           Revision Control History                          #
#*****************************************************************************#
#  V1.0.0: 2021-06-07, JO:   Initial version of the example (py for XML code) #
###############################################################################

# calculation of prev pattern: 1-->6, 2--> 1, 3-->3,...
prev_dict = {
1: 6,
2: 1,
3: 2,
4: 3,
5: 4,
6: 5}
# calculation of next pattern: 1-->2, 2--> 3, ..., 6-->1
next_dict = {
1: 2,
2: 3,
3: 4,
4: 5,
5: 6,
6: 1}

hall_y_dict = {1:{0:125.63598, 1:120.34429}, 2:{0:133.57352, 1:128.28183}, 3:{0:141.51107, 1:136.21938}}


def update_hall_graph():
  # hall_list with dummy entry as entry 0 to use same incex as in xml
  hall_list = [0]
  for ptn in range(1, 7):
    # 1...6
    # combo_name, e.g. BLDC_HALL_PTN1
    combo_name = 'BLDC_HALL_PTN' + str(ptn)

    hall1 =  int(globals()['BLDC_HALL1_PTN' + str(ptn)].__dict__['checked'])
    hall2 =  int(globals()['BLDC_HALL2_PTN' + str(ptn)].__dict__['checked'])
    hall3 =  int(globals()['BLDC_HALL3_PTN' + str(ptn)].__dict__['checked'])
    
    # create list of all hall signals to make the vertical lines afterwards
    hall_list.append({1:hall1, 2:hall2, 3:hall3})
    
    # place hall signals
    globals()['Y_HALL1_PTN' + str(ptn)].value = hall_y_dict[1][hall1]
    globals()['Y_HALL2_PTN' + str(ptn)].value = hall_y_dict[2][hall2]
    globals()['Y_HALL3_PTN' + str(ptn)].value = hall_y_dict[3][hall3]
    
  # vertical lines if hall changes
  for ptn in range(1, 7):
    # 1...6
    gen_vis_name = 'VIS_HALL_PTN' + str(ptn) + '_CHANGE'
    globals()[gen_vis_name].text = 'hidden'
    for hall in range(1, 4):
      # 1...3
      vis_name = 'VIS_HALL' + str(hall) + '_PTN' + str(ptn) + '_CHANGE'
      globals()[vis_name].text = 'hidden'
      prev_ptn_num = prev_dict[ptn]
      if hall_list[ptn][hall] !=  hall_list[prev_ptn_num][hall]:
        # make line visible in calse the pattern changed
        globals()[vis_name].text = 'visible'
        globals()[gen_vis_name].text = 'visible'
        
  # update labels for Hall signals
  HALL1_GPIO.text = "Hall 1 (" + BLDC_HALL1_INPUT.currentText[:4] + ")"
  HALL2_GPIO.text = "Hall 2 (" + BLDC_HALL2_INPUT.currentText[:4] + ")"
  HALL3_GPIO.text = "Hall 3 (" + BLDC_HALL3_INPUT.currentText[:4] + ")"
    
  application.runScript("setDef(_hall.update=1)")
  
# initilize graph with currently selected pattern and update the graph
update_hall_graph()
application.runScript("setDef(_hall.update=1)")

# connect to all checkboxes
BLDC_HALL1_PTN1.connect('stateChanged(int)', update_hall_graph)
BLDC_HALL1_PTN2.connect('stateChanged(int)', update_hall_graph)
BLDC_HALL1_PTN3.connect('stateChanged(int)', update_hall_graph)
BLDC_HALL1_PTN4.connect('stateChanged(int)', update_hall_graph)
BLDC_HALL1_PTN5.connect('stateChanged(int)', update_hall_graph)
BLDC_HALL1_PTN6.connect('stateChanged(int)', update_hall_graph)
BLDC_HALL2_PTN1.connect('stateChanged(int)', update_hall_graph)
BLDC_HALL2_PTN2.connect('stateChanged(int)', update_hall_graph)
BLDC_HALL2_PTN3.connect('stateChanged(int)', update_hall_graph)
BLDC_HALL2_PTN4.connect('stateChanged(int)', update_hall_graph)
BLDC_HALL2_PTN5.connect('stateChanged(int)', update_hall_graph)
BLDC_HALL2_PTN6.connect('stateChanged(int)', update_hall_graph)
BLDC_HALL3_PTN1.connect('stateChanged(int)', update_hall_graph)
BLDC_HALL3_PTN2.connect('stateChanged(int)', update_hall_graph)
BLDC_HALL3_PTN3.connect('stateChanged(int)', update_hall_graph)
BLDC_HALL3_PTN4.connect('stateChanged(int)', update_hall_graph)
BLDC_HALL3_PTN5.connect('stateChanged(int)', update_hall_graph)
BLDC_HALL3_PTN6.connect('stateChanged(int)', update_hall_graph)
BLDC_HALL1_INPUT.connect('currentIndexChanged(int)', update_hall_graph)
BLDC_HALL2_INPUT.connect('currentIndexChanged(int)', update_hall_graph)
BLDC_HALL3_INPUT.connect('currentIndexChanged(int)', update_hall_graph)


#def main():
#    load()
#    
#    
#if __name__ == "__main__":
#    main()