#<checksum>1dfd4fa256f70716e2554ac63a0197ad8ab1d7fd4acbb8142a22aac3e9b43525</checksum>

#
# \file     graph_phases.py
#
# \brief    python script update the graph with the phases according to XML settings
#
# \version  V1.0.0
# \date     15 May 2021
#

###############################################################################
#                              Author(s) Identity                             #
#*****************************************************************************#
#  Initials     Name                                                          #
#  -------------------------------------------------------------------------- #
#  JO           Julia Ott                                                     #
###############################################################################

###############################################################################
#                           Revision Control History                          #
#*****************************************************************************#
#  V1.0.0: 2021-05-14, JO:   Initial version of the example (py for XML code) #
###############################################################################

# calculation of prev pattern: 1-->6, 2--> 1, 3-->3,...
prev_dict = {
1: '6',
2: '1',
3: '2',
4: '3',
5: '4',
6: '5'}
# calculation of next pattern: 1-->2, 2--> 3, ..., 6-->1
next_dict = {
1: '2',
2: '3',
3: '4',
4: '5',
5: '6',
6: '1'}
# calculation on concurrent phases: 1-->2 and 3, 2-->1 and 3, 3-->1 and 2
conc_a_dict = {
1: '2',
2: '3',
3: '1'}
conc_b_dict = {
1: '3',
2: '1',
3: '2'}

# graph elements
graph_element_list = ['LOW', 'HI', 'MID', 'ZSUP', 'ZSDOWN', 'ZHUP', 'ZHDOWN', 'PWM', 'UNDEF']

# define which element is visible in case the current pattern in 'High Z'
# explanation of key:
# key has three digits, each int of 0...3 (0: High Z, 1: HS On, 2: LS On, 3: PWM
# 1st digit: previous pattern of the current phase
# 2nd digit: current pattern of the first other phase
# 3rd digit: current pattern of the second other phase
visible_element_dict = {
'000':  'UNDEF',        # prev: Z,   conc: Z,   Z
'001':  'UNDEF',        # prev: Z,   conc: Z,   HS
'002':  'UNDEF',        # prev: Z,   conc: Z,   LS
'003':  'UNDEF',        # prev: Z,   conc: Z,   PWM
'010':  'UNDEF',        # prev: Z,   conc: HS,  Z
'011':  'UNDEF',        # prev: Z,   conc: HS,  HS
'012':  'UNDEF',        # prev: Z,   conc: HS,  LS
'013':  'UNDEF',        # prev: Z,   conc: HS,  PWM
'020':  'UNDEF',        # prev: Z,   conc: LS,  Z
'021':  'UNDEF',        # prev: Z,   conc: LS,  HS
'022':  'UNDEF',        # prev: Z,   conc: LS,  LS
'023':  'UNDEF',        # prev: Z,   conc: LS,  PWM
'030':  'UNDEF',        # prev: Z,   conc: PWM, Z
'031':  'UNDEF',        # prev: Z,   conc: PWM, HS
'032':  'UNDEF',        # prev: Z,   conc: PWM, LS
'033':  'UNDEF',        # prev: Z,   conc: PWM, PWM
'100':  'UNDEF',        # prev: HS,  conc: Z,   Z
'101':  'UNDEF',        # prev: HS,  conc: Z,   HS
'102':  'UNDEF',        # prev: HS,  conc: Z,   LS
'103':  'UNDEF',        # prev: HS,  conc: Z,   PWM
'110':  'UNDEF',        # prev: HS,  conc: HS,  Z
'111':  'UNDEF',        # prev: HS,  conc: HS,  HS
'112':  'UNDEF',        # prev: HS,  conc: HS,  LS
'113':  'ZHDOWN',  # prev: HS,  conc: HS,  PWM
'120':  'UNDEF',        # prev: HS,  conc: LS,  Z
'121':  'UNDEF',        # prev: HS,  conc: LS,  HS
'122':  'UNDEF',        # prev: HS,  conc: LS,  LS
'123':  'ZHDOWN',  # prev: HS,  conc: LS,  PWM
'130':  'UNDEF',        # prev: HS,  conc: PWM, Z
'131':  'ZHDOWN',  # prev: HS,  conc: PWM, HS
'132':  'ZHDOWN',  # prev: HS,  conc: PWM, LS
'133':  'UNDEF',        # prev: HS,  conc: PWM, PWM
'200':  'UNDEF',        # prev: LS,  conc: Z,   Z
'201':  'UNDEF',        # prev: LS,  conc: Z,   HS
'202':  'UNDEF',        # prev: LS,  conc: Z,   LS
'203':  'UNDEF',        # prev: LS,  conc: Z,   PWM
'210':  'UNDEF',        # prev: LS,  conc: HS,  Z
'211':  'UNDEF',        # prev: LS,  conc: HS,  HS
'212':  'UNDEF',        # prev: LS,  conc: HS,  LS
'213':  'ZSUP',    # prev: LS,  conc: HS,  PWM
'220':  'UNDEF',        # prev: LS,  conc: LS,  Z
'221':  'UNDEF',        # prev: LS,  conc: LS,  HS
'222':  'UNDEF',        # prev: LS,  conc: LS,  LS
'223':  'ZSUP',    # prev: LS,  conc: LS,  PWM
'230':  'UNDEF',        # prev: LS,  conc: PWM, Z
'231':  'ZSUP',    # prev: LS,  conc: PWM, HS
'232':  'ZSUP',    # prev: LS,  conc: PWM, LS
'233':  'UNDEF',        # prev: LS,  conc: PWM, PWM
'300':  'UNDEF',        # prev: PWM, conc: Z,   Z
'301':  'UNDEF',        # prev: PWM, conc: Z,   HS
'302':  'UNDEF',        # prev: PWM, conc: Z,   LS
'303':  'UNDEF',        # prev: PWM, conc: Z,   PWM
'310':  'UNDEF',        # prev: PWM, conc: HS,  Z
'311':  'UNDEF',        # prev: PWM, conc: HS,  HS
'312':  'UNDEF',        # prev: PWM, conc: HS,  LS
'313':  'ZHUP',    # prev: PWM, conc: HS,  PWM
'320':  'UNDEF',        # prev: PWM, conc: LS,  Z
'321':  'UNDEF',      # prev: PWM, conc: LS,  HS
'322':  'UNDEF',        # prev: PWM, conc: LS,  LS
'323':  'ZSDOWN',  # prev: PWM, conc: LS,  PWM
'330':  'UNDEF',        # prev: PWM, conc: PWM, Z
'331':  'ZHUP',    # prev: PWM, conc: PWM, HS
'332':  'ZSDOWN',  # prev: PWM, conc: PWM, LS
'333':  'UNDEF'        # prev: PWM, conc: PWM, PWM
}

# Update the graph element specified by ph and ptn number
class update_graph_element:
  def __init__(self, ph, ptn):
    self.ph = ph
    self.ptn = ptn
    self.name = 'BLDC_PH' + str(self.ph) + '_PTN' + str(self.ptn)
    self.val = globals()[self.name].__dict__['currentData']
    self.sel = globals()[self.name].__dict__['currentText']
    self.vis_name_begin = 'VIS_' + self.name[5:] + '_'

  def set_all_hidden(self):
    for graph_element in graph_element_list:
      globals()[self.vis_name_begin + graph_element].text = 'hidden'

  def get_visible_graph_element(self, prev_val, conc_a_val, conc_b_val):
    if self.sel == 'HS On':
      return 'HI' # 1xxx
    if self.sel == 'LS On':
      return 'LOW' # 2xxx
    if self.sel == 'PWM':
      return 'PWM' # 3xxx
    if self.sel == 'High Z': # 0xxx
      key = str(prev_val) +  str(conc_a_val) +  str(conc_b_val)
      #print(key)
      return visible_element_dict[key]
    
  def show_element(self, element):
    globals()[self.vis_name_begin + str(element)].text = 'visible'

  def update(self, prev_val, conc_a_val, conc_b_val):
    self.set_all_hidden()
    graph_element = self.get_visible_graph_element(prev_val, conc_a_val, conc_b_val)
    self.show_element(graph_element)
    

# The combo element 'combo' has chenged, 
# so its graph element and all graph elements that depend on it need to be updated
class update_all_dependent_graph_elements:
  def __init__(self, combo):
    # objectName is BLDC_PHx_PTNy, with x any 0 numbers (x = 1...3, y = 1...6)
    ph = int(combo.__dict__['objectName'][7])
    ptn = int(combo.__dict__['objectName'][12])
    self.me = update_graph_element(ph, ptn)
    
    # pattern that are relevant for this one: prev ptn and two conc ph
    # pattern that depend on this one: next ptn and two conc ph
    prev_ptn_num = prev_dict[self.me.ptn]
    next_ptn_num = next_dict[self.me.ptn]
    conc_a_ph_num = conc_a_dict[self.me.ph]
    conc_b_ph_num = conc_b_dict[self.me.ph]
   
    self.prev = update_graph_element(self.me.ph, prev_ptn_num)
    self.conc_a_prev = update_graph_element(conc_a_ph_num, prev_ptn_num)
    self.conc_b_prev = update_graph_element(conc_b_ph_num, prev_ptn_num)
    self.conc_a = update_graph_element(conc_a_ph_num, self.me.ptn)
    self.conc_b = update_graph_element(conc_b_ph_num, self.me.ptn)
    self.next = update_graph_element(self.me.ph, next_ptn_num)
    self.conc_a_next = update_graph_element(conc_a_ph_num, next_ptn_num)
    self.conc_b_next = update_graph_element(conc_b_ph_num, next_ptn_num)
    
    self.me.update(self.prev.val, self.conc_a.val, self.conc_b.val)
    self.conc_a.update(self.conc_a_prev.val, self.me.val, self.conc_b.val)
    self.conc_b.update(self.conc_b_prev.val, self.me.val, self.conc_a.val)
    self.next.update(self.me.val, self.conc_a_next.val, self.conc_b_next.val)  


def fcn(element): 
  def callback(value): 
  # Code of the callback here 
    # update graph for the current element
    update_all_dependent_graph_elements(element)

    # update graph
    application.runScript("setDef(_phases.update=1)")
    
    # debug print
    #print('Graph updated!')
  return callback 
  
  
# initilize graph with currently selected pattern and update the graph
# PH1 also sets PH2 and PH3, so no need to initialize them as well
update_all_dependent_graph_elements(BLDC_PH1_PTN1)
update_all_dependent_graph_elements(BLDC_PH1_PTN2)
update_all_dependent_graph_elements(BLDC_PH1_PTN3)
update_all_dependent_graph_elements(BLDC_PH1_PTN4)
update_all_dependent_graph_elements(BLDC_PH1_PTN5)
update_all_dependent_graph_elements(BLDC_PH1_PTN6)
application.runScript("setDef(_phases.update=1)")

# connect to all combos
BLDC_PH1_PTN1.connect('currentIndexChanged(int)', fcn(BLDC_PH1_PTN1))
BLDC_PH1_PTN2.connect('currentIndexChanged(int)', fcn(BLDC_PH1_PTN2))
BLDC_PH1_PTN3.connect('currentIndexChanged(int)', fcn(BLDC_PH1_PTN3))
BLDC_PH1_PTN4.connect('currentIndexChanged(int)', fcn(BLDC_PH1_PTN4))
BLDC_PH1_PTN5.connect('currentIndexChanged(int)', fcn(BLDC_PH1_PTN5))
BLDC_PH1_PTN6.connect('currentIndexChanged(int)', fcn(BLDC_PH1_PTN6))
BLDC_PH2_PTN1.connect('currentIndexChanged(int)', fcn(BLDC_PH2_PTN1))
BLDC_PH2_PTN2.connect('currentIndexChanged(int)', fcn(BLDC_PH2_PTN2))
BLDC_PH2_PTN3.connect('currentIndexChanged(int)', fcn(BLDC_PH2_PTN3))
BLDC_PH2_PTN4.connect('currentIndexChanged(int)', fcn(BLDC_PH2_PTN4))
BLDC_PH2_PTN5.connect('currentIndexChanged(int)', fcn(BLDC_PH2_PTN5))
BLDC_PH2_PTN6.connect('currentIndexChanged(int)', fcn(BLDC_PH2_PTN6))
BLDC_PH3_PTN1.connect('currentIndexChanged(int)', fcn(BLDC_PH3_PTN1))
BLDC_PH3_PTN2.connect('currentIndexChanged(int)', fcn(BLDC_PH3_PTN2))
BLDC_PH3_PTN3.connect('currentIndexChanged(int)', fcn(BLDC_PH3_PTN3))
BLDC_PH3_PTN4.connect('currentIndexChanged(int)', fcn(BLDC_PH3_PTN4))
BLDC_PH3_PTN5.connect('currentIndexChanged(int)', fcn(BLDC_PH3_PTN5))
BLDC_PH3_PTN6.connect('currentIndexChanged(int)', fcn(BLDC_PH3_PTN6))


#def main():
#    load()
#    
#    
#if __name__ == "__main__":
#    main()