/*
 ***********************************************************************************************************************
 *
 * Copyright (c) 2021-2023, Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** BG           Blandine Guillot                                              **
** JO           Julia Ott                                                     **
** EE           Erich Englbrecht                                              **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2021-03-02, EE:   EP-721 Initial version                           **
** V1.0.1: 2021-10-06, JO:   EP-949: Corrected memory layout (IROM1 size,     **
**                           IRAM1 start and size, IRAM2 size)                **
** V1.0.2: 2021-10-15, JO:   EP-962: Updated NAC time                         **
** V1.0.3: 2021-10-22, BG:   EP-814: Added return code for TLE_init()         **
**                           Removed clearing of status registers, should be  **
**                           done in the init functions if they are passed    **
** V1.0.4: 2021-11-11, JO:   EP-937: Updated copyright and branding           **
** V1.0.5: 2021-12-20, JO:   EP-977: Added '--diag_suppress 1609' to Asm Misc **
**                           Control to remove compiler warning               **
** V1.1.0: 2023-04-18, JO:   EP-1235: Changed to C startup file               **
** V1.2.0: 2024-06-14, JO:   EP-1480: Disabled  warning 'unsafe buffer usage' **
**                           (ARM compiler for Embedded version >6.21)        **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** PMU: Stop mode                                                             **
********************************************************************************
** After a Reset, the system is in normal mode.                               **
** When GPIO pin 0.1 is set to high, the system enters stop mode.             **
** When GPIO pin 1.1 (wakeup trigger) is set to high, the system leaves the   **
** stop mode.                                                                 **
** The LED at P0.2 indicates the mode: ON: normal mode, OFF: stop mode.       **                                          **
*******************************************************************************/

/*******************************************************************************
**                                  Includes                                  **
*******************************************************************************/
#include "tle_device.h"
#include "types.h"
#include "gpio.h"
#include "pmu.h"

/*******************************************************************************
**                                 Constants                                  **
*******************************************************************************/
#define GPIO_P01_HIGH (0x1U)


sint32 main(void)
{
  sint8 s8_returnCode;

  /* Clear Watchdog fail status */
  PMU_clrFailSafeWatchdogFailSts();

  /* Initialization of hardware modules based on Config Wizard configuration. */
  s8_returnCode = TLE_init();
  
  if (s8_returnCode != ERR_LOG_SUCCESS)
  {
    /* Place your code here to handle an initialization error */
  }

  for (;;)
  {
    /* Main watchdog1 (WDT1) service */
    (void) PMU_serviceFailSafeWatchdog();
    
    /* Check if GPIO 0.1 is high. */
    if (GPIO_P01_HIGH == GPIO_getP01State())
    {
      GPIO_setP02State(GPIO_STATE_LOW);
      /* Enter stop mode. P1.1 is configured as wakeup signal. */
      SCU_enterStopMode();
    }
    else
    {
      /* If the cpu is not in stop mode set GPIO 0.2 to high. */
      GPIO_setP02State(GPIO_STATE_HIGH);
    }
  }
}
