/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** AA           Abhilash Abhilash                                             **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2020-10-21, AA:   EP-924: Initial version                          **
*******************************************************************************/

#ifndef _SECURITY_ACCESS_H
#define _SECURITY_ACCESS_H

/*******************************************************************************
**                                  Includes                                  **
*******************************************************************************/
#include "types.h"
#include "bootrom.h"

/*******************************************************************************
**                          Global Macro Declarations                         **
*******************************************************************************/
/** \brief IO buffer size */ 
#define TLE989X_AES_IO_BUFFER_SIZE (32u)

 /** \brief Subfunction for SEED request */
#define SEED_REQUEST (0x01u)
 
 /** \brief Subfunction for KEY request */
#define KEY_REQUEST (0x02u)

/** \brief Message length */              
#define REQUEST_LENGTH (18u)

/** \brief CMAC length */              
#define CMAC_LENGTH (16u)

/** \brief Key slot to be used for encryption. Key slot '0' is reserved. */
#define KEY_ID (1u)

/** \brief Invalid key, NRC */ 
#define WRONG_KEY (0x35u)    

/**\brief Incorrect subfunction, NRC */
#define SUBFUNC_ERROR (0x12u)      

/**\brief Incorrect sequence, NRC */
#define SEQUENCE_ERROR (0x24u)     

/**\brief Incorrect length, NRC*/
#define LENGTH_ERROR (0x13u)      

/**\brief Service not supported, NRC*/                      
#define SERVICE_NOT_SUPPORTED (0x11u)     

/**\brief +ve response indication byte for security access (0x27 + 0x40) */
#define POS_RESP_ID (0x67u)      

/**\brief -ve response indication byte */
#define NEG_RESP_ID (0x7Fu)      

/**\brief +ve response length */
#define POS_RESP_LENGTH (0x02u)      

 /**\brief -ve response length */
#define NEG_RESP_LENGTH (0x03u)     

/**\brief Request ID */
#define SECURITY_ACCESS_REQ_SERVICE_ID (0x27u)      

/**\brief Update length used for encryption or decryption */
#define AES_UPDATE_LENGTH (32u)      

/**\brief Offset value */
#define OFFSET_LENGTH (8u)       

/*******************************************************************************
**                          Global Type Declarations                          **
*******************************************************************************/

/** \struct tDiagMsg
 *  \brief This struct lists the parameters for the diagnostic request and response message
 */
typedef struct _tDiagMsg
{
  uint8  u8_req[TLE989X_AES_IO_BUFFER_SIZE + OFFSET_LENGTH];   /** \brief Request message buffer */ 
  uint32 u32_reqLength;                                        /** \brief Request message length */ 
  uint8  u8_resp[TLE989X_AES_IO_BUFFER_SIZE];                  /** \brief Response message buffer */ 
  uint32 u32_respLength;                                       /** \brief Response message length */ 
} tDiagMsg;


/*******************************************************************************
**                        Global Function Declarations                        **
*******************************************************************************/

void serviceSecurityAccess(tDiagMsg *sp_msg);

#endif  /* _SECURUTY_ACCESS_H  */

