/*
 ***********************************************************************************************************************
 *
 * Copyright (c) 2022-2023, Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** CK           Chander Kumar                                                 **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V0.0.1: 2022-08-18, CK:   EP-1241: Initial version                         **
** V1.1.0: 2023-04-18, JO:   EP-1235: Changed to C startup file               **
** V1.2.0: 2024-06-14, JO:   EP-1480: Disabled  warning 'unsafe buffer usage' **
**                           (ARM compiler for Embedded version >6.21)        **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** T20: Capturing a PWM signal via T20                                        **
********************************************************************************
** The timer T20 used to capture a PWM signal at GPIO P0.3.                   **
** The measured ticks (low phase, period) are stored in the static variables  **
** capDC and capPer.                                                          **
*******************************************************************************/

/*******************************************************************************
**                                  Includes                                  **
*******************************************************************************/
#include "tle_device.h"
#include "types.h"

/*******************************************************************************
**                                 Variables                                  **
*******************************************************************************/
static uint16 capPer, capDC;
static uint16 bDC_Per;

/*******************************************************************************
**                           Function Declarations                            **
*******************************************************************************/
void PWM_Capture(void);


sint32 main(void)
{
  sint8 s8_returnCode;
  
  /* Clear watchdog fail status */
  PMU_clrFailSafeWatchdogFailSts();
  
  /* Initialization of hardware modules based on Config Wizard configuration */
  s8_returnCode = TLE_init();
  
  if (s8_returnCode != ERR_LOG_SUCCESS)
  {
    /* Place your code here to handle an initialization error */
  }
  
  bDC_Per = 0;
	
  /*****************************************************************************
  ** Main endless loop                                                        **
  *****************************************************************************/
  for (;;)
  {
    /* Main watchdog service */
    (void)PMU_serviceFailSafeWatchdog();    
    
  }
}


/* Callback function for Timer2 */
void PWM_Capture(void)
{
  /* Timer20 in run mode */
  if(T20->CON.bit.TR2 == 1)
  {
    if (bDC_Per == 0u)
    {
      /* Get the duty cycle */
      capDC = T20_getCapRelVal();
      /* Next capture on falling edge */
      T20->MOD.bit.EDGESEL = 0u;
      bDC_Per = 1u;
    }
    else
    {
      /* Get the PWM period */
      capPer = T20_getCapRelVal();
      /* Next capture on rising edge */
      T20->MOD.bit.EDGESEL = 1u;
      bDC_Per = 0u;
      /* Stop Timer20 */
      T20_stop();
      /* Reset Timer20 */
      T20_setCntVal(0);
    }
  }
}
