/******************************************************************************
 * @file     startup_TLE989x.s
 * @brief    CMSIS Cortex-M3 Core Device Startup File for
 *           Infineon TLE989x Device Series
 * @version  V0.1.1
 * @date     11. Nov. 2021
 *
 * Copyright (c) Infineon Technologies AG. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ******************************************************************************/

/****************************** Version History *******************************
 * V0.1.0, 10. Nov. 2021, Initial version
 * V0.1.1, 11. Nov. 2021, EP-937: Updated copyright and branding
 ******************************************************************************/

/* =============== START : MACRO DEFINITION MACRO DEFINITION ================ */
 
.macro Entry Handler
    .long \Handler
.endm

.macro Insert_ExceptionHandler Handler_Func 
    .weak \Handler_Func
    .thumb_set \Handler_Func, Default_Handler
.endm

/* ================= END : MACRO DEFINITION MACRO DEFINITION ================ */

/* ==================== START OF VECTOR TABLE DEFINITION ==================== */

/* Vector Table - This gets programed into VTOR register by onchip BootROM */
    .syntax unified

    .section .reset
    
	.align 2
    .globl  __Vectors
    .type   __Vectors, %object
__Vectors:
    .long   __initial_sp                /* Top of Stack                 */
    .long   Reset_Handler               /* Reset Handler                */
    Entry   NMI_Handler                 /* NMI Handler                  */
    Entry   HardFault_Handler           /* Hard Fault Handler           */
    Entry   MemManage_Handler           /* MPU Fault Handler            */
    Entry   BusFault_Handler            /* Bus Fault Handler            */
    Entry   UsageFault_Handler          /* Usage Fault Handler          */
    .long   0                           /* Reserved                     */
    .long   0                           /* Reserved                     */
    .long   0                           /* Reserved                     */
    .long   0                           /* Reserved                     */
    Entry   SVC_Handler                 /* SVCall Handler               */
    Entry   DebugMon_Handler            /* Debug Monitor Handler        */
    .long   0                           /* Reserved                     */
    Entry   PendSV_Handler              /* PendSV Handler               */
    Entry   SysTick_Handler             /* SysTick Handler              */

    /* Interrupt Handlers for Service Requests (SR) from TLE989x Peripherals */
    Entry   NVIC_IRQ0_Handler           /* Handler for PMU, BDRV, CSC, ARVG */
    Entry   NVIC_IRQ1_Handler           /* Handler for PMU, BDRV, CSC, ARVG */
    Entry   NVIC_IRQ2_Handler           /* Handler for CCU7 */
    Entry   NVIC_IRQ3_Handler           /* Handler for CCU7 */
    Entry   NVIC_IRQ4_Handler           /* Handler for CCU7 */
    Entry   NVIC_IRQ5_Handler           /* Handler for CCU7 */
    Entry   0x000000c1                  /* Handler for MEMCTRL */
    Entry   NVIC_IRQ7_Handler           /* Handler for GPT12E */
    Entry   NVIC_IRQ8_Handler           /* Handler for GPT12E */
    Entry   NVIC_IRQ9_Handler           /* Handler for Timer2 */
    Entry   NVIC_IRQ10_Handler          /* Handler for ADC2 */
    Entry   NVIC_IRQ11_Handler          /* Handler for ADC2 */
    Entry   NVIC_IRQ12_Handler          /* Handler for MON */
    Entry   NVIC_IRQ13_Handler          /* Handler for MON */
    Entry   NVIC_IRQ14_Handler          /* Handler for ADC1 */
    Entry   NVIC_IRQ15_Handler          /* Handler for ADC1 */
    Entry   NVIC_IRQ16_Handler          /* Handler for ADC1 */
    Entry   NVIC_IRQ17_Handler          /* Handler for ADC1 */
    Entry   NVIC_IRQ18_Handler          /* Handler for BEMF, SDADC */
    Entry   NVIC_IRQ19_Handler          /* Handler for BEMF, SDADC */
    Entry   NVIC_IRQ20_Handler          /* Handler for EXTINT */
    Entry   NVIC_IRQ21_Handler          /* Handler for EXTINT */
    Entry   NVIC_IRQ22_Handler          /* Handler for UART0/1, LIN */
    Entry   NVIC_IRQ23_Handler          /* Handler for UART0/1, LIN */
    Entry   NVIC_IRQ24_Handler          /* Handler for SSC0/1 */
    Entry   NVIC_IRQ25_Handler          /* Handler for SSC0/1 */
    Entry   NVIC_IRQ26_Handler          /* Handler for MultiCAN */
    Entry   NVIC_IRQ27_Handler          /* Handler for MultiCAN */
    Entry   NVIC_IRQ28_Handler          /* Handler for MultiCAN */
    Entry   NVIC_IRQ29_Handler          /* Handler for DMA */
    Entry   NVIC_IRQ30_Handler          /* Handler for DMA */
    Entry   NVIC_IRQ31_Handler          /* Handler for Timer21 */

    .size  __Vectors, . - __Vectors
    
/* ===================== END OF VECTOR TABLE DEFINITION ===================== */

/* ======================== START OF VECTOR ROUTINES ======================== */

	.align	1
    .thumb

/* Reset Handler */
    .thumb_func
    .globl  Reset_Handler
    .type   Reset_Handler, %function
Reset_Handler:
    ldr r0,=__initial_sp
    msr msp, r0
    isb

#ifndef __SKIP_SYSTEM_INIT
    ldr  r0, =SystemInit
    blx  r0
#endif

/* Initialize data
 *
 *  Between symbol address __copy_table_start__ and __copy_table_end__,
 *  there are array of triplets, each of which specify:
 *    offset 0: LMA of start of a section to copy from
 *    offset 4: VMA of start of a section to copy to
 *    offset 8: size of the section to copy. Must be multiply of 4
 *
 *  All addresses must be aligned to 4 bytes boundary.
 */
	ldr	r4, =__copy_table_start__
	ldr	r5, =__copy_table_end__

.L_loop0:
	cmp	r4, r5
	bge	.L_loop0_done
	ldr	r1, [r4]
	ldr	r2, [r4, #4]
	ldr	r3, [r4, #8]

.L_loop0_0:
	subs	r3, #4
	ittt	ge
	ldrge	r0, [r1, r3]
	strge	r0, [r2, r3]
	bge	.L_loop0_0

	adds	r4, #12
	b	.L_loop0

.L_loop0_done:

/* Zero initialized data 
 *  Between symbol address __zero_table_start__ and __zero_table_end__,
 *  there are array of tuples specifying:
 *    offset 0: Start of a BSS section
 *    offset 4: Size of this BSS section. Must be multiply of 4
 *
 *  Define __SKIP_BSS_CLEAR to disable zeroing uninitialzed data in startup.
 */    
#ifndef __SKIP_BSS_CLEAR
	ldr	r3, =__zero_table_start__
	ldr	r4, =__zero_table_end__

.L_loop2:
	cmp	r3, r4
	bge	.L_loop2_done
	ldr	r1, [r3]
	ldr	r2, [r3, #4]
	movs	r0, 0

.L_loop2_0:
	subs	r2, #4
	itt	ge
	strge	r0, [r1, r2]
	bge	.L_loop2_0

	adds	r3, #8
	b	.L_loop2
.L_loop2_done:    
#endif /* __SKIP_BSS_CLEAR */
   
#ifndef __SKIP_LIBC_INIT_ARRAY
    ldr  r0, =__libc_init_array
    blx  r0
#endif

    ldr  r0, =main
    blx  r0

.align 2
__copy_table_start__:
    .long __data_load, __data_start, __data_size
    .long __ram_code_load, __ram_code_start, __ram_code_size
__copy_table_end__:

__zero_table_start__:
    .long __bss_start, __bss_size
__zero_table_end__:
    
	.pool
    .size   Reset_Handler,.-Reset_Handler
    
/* ========================================================================== */
/* ================== START OF INTERRUPT HANDLER DEFINITION ================= */

/* Default exception Handlers - Users may override this default functionality by
   defining handlers of the same name in their C code */
    .align	1
    .thumb_func
    .weak Default_Handler
    .type Default_Handler, %function
Default_Handler:
    b .
    .size Default_Handler, . - Default_Handler

     Insert_ExceptionHandler NMI_Handler
     Insert_ExceptionHandler HardFault_Handler
     Insert_ExceptionHandler MemManage_Handler
     Insert_ExceptionHandler BusFault_Handler
     Insert_ExceptionHandler UsageFault_Handler
     Insert_ExceptionHandler SVC_Handler
     Insert_ExceptionHandler DebugMon_Handler
     Insert_ExceptionHandler PendSV_Handler
     Insert_ExceptionHandler SysTick_Handler

     Insert_ExceptionHandler NVIC_IRQ0_Handler 
     Insert_ExceptionHandler NVIC_IRQ1_Handler 
     Insert_ExceptionHandler NVIC_IRQ2_Handler 
     Insert_ExceptionHandler NVIC_IRQ3_Handler 
     Insert_ExceptionHandler NVIC_IRQ4_Handler 
     Insert_ExceptionHandler NVIC_IRQ5_Handler 
     Insert_ExceptionHandler NVIC_IRQ7_Handler 
     Insert_ExceptionHandler NVIC_IRQ8_Handler 
     Insert_ExceptionHandler NVIC_IRQ9_Handler 
     Insert_ExceptionHandler NVIC_IRQ10_Handler
     Insert_ExceptionHandler NVIC_IRQ11_Handler
     Insert_ExceptionHandler NVIC_IRQ12_Handler
     Insert_ExceptionHandler NVIC_IRQ13_Handler
     Insert_ExceptionHandler NVIC_IRQ14_Handler
     Insert_ExceptionHandler NVIC_IRQ15_Handler
     Insert_ExceptionHandler NVIC_IRQ16_Handler
     Insert_ExceptionHandler NVIC_IRQ17_Handler
     Insert_ExceptionHandler NVIC_IRQ18_Handler
     Insert_ExceptionHandler NVIC_IRQ19_Handler
     Insert_ExceptionHandler NVIC_IRQ20_Handler
     Insert_ExceptionHandler NVIC_IRQ21_Handler
     Insert_ExceptionHandler NVIC_IRQ22_Handler
     Insert_ExceptionHandler NVIC_IRQ23_Handler
     Insert_ExceptionHandler NVIC_IRQ24_Handler
     Insert_ExceptionHandler NVIC_IRQ25_Handler
     Insert_ExceptionHandler NVIC_IRQ26_Handler
     Insert_ExceptionHandler NVIC_IRQ27_Handler
     Insert_ExceptionHandler NVIC_IRQ28_Handler
     Insert_ExceptionHandler NVIC_IRQ29_Handler
     Insert_ExceptionHandler NVIC_IRQ30_Handler
     Insert_ExceptionHandler NVIC_IRQ31_Handler

/* =================== END OF INTERRUPT HANDLER DEFINITION ================== */

    .end
