/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/
/**
 * \file     ssc.h
 *
 * \brief    High-Speed Synchronous Serial Interface low level access library
 *
 * \version  V0.3.8
 * \date     12. Nov 2021
 *
 * \note
 */

/** \addtogroup SSC_api
 *  @{
 */

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** DM           Daniel Mysliwitz                                              **
** BG           Blandine Guillot                                              **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V0.1.0: 2019-10-28, DM:   Initial version                                  **
** V0.2.0: 2020-04-28, BG:   Updated revision history format                  **
** V0.3.0: 2020-08-26, BG:   Added first functions                            **
** V0.3.1: 2020-09-16, BG:   Added interrupt enable/disable functions         **
** V0.3.2: 2020-10-21, BG:   EP-539: Considered the enable checkbox in CW in  **
**                           the initialization function                      **
** V0.3.3: 2020-11-12, JO:   EP-590: Removed \param none and \return none to  **
**                           avoid doxygen warning                            **
**                           Added end of group for doxygen                   **
** V0.3.4: 2020-11-20, BG:   EP-610: Corrected MISRA 2012 errors              **
**                           The following rules are globally deactivated:    **
**                           - Info 774: Boolean within 'if' always evaluates **
**                             to False/True                                  **
** V0.3.5: 2020-12-18, BG:   EP-652: Corrected name of error code variable    **
** V0.3.6: 2021-04-06, BG:   EP-760: Replaced if instructions to check if the **
**                           module is enabled with preprocessor directives to**
**                           avoid compiler warnings                          **
** V0.3.7: 2021-05-18, JO:   EP-818: Corrected name of deprecated functions   **
** V0.3.8: 2021-11-12, JO:   EP-937: Updated copyright and branding           **
*******************************************************************************/

#ifndef _SSC_H
#define _SSC_H

/*******************************************************************************
**                                  Includes                                  **
*******************************************************************************/

#include "types.h"
#include "tle989x.h"
#include "tle_variants.h"
#include "ssc_defines.h"
#include "scu_defines.h"

/*******************************************************************************
**                        Global Constant Declarations                        **
*******************************************************************************/

/*******************************************************************************
**                          Global Type Declarations                          **
*******************************************************************************/

/*******************************************************************************
**                          Global Macro Declarations                         **
*******************************************************************************/

/*******************************************************************************
**                        Global Function Declarations                        **
*******************************************************************************/

sint8 SSC0_init(void);
sint8 SSC1_init(void);
INLINE uint64 SSC0_getTXvalue(void);
INLINE void SSC0_setTXvalue(uint64 u64_TXvalue);
INLINE uint64 SSC0_getRXvalue(void);
INLINE uint8 SSC0_getBitCnt(void);
INLINE uint8 SSC0_getBusySts(void);
INLINE void SSC0_enEmptyTXBufferInt(void);
INLINE void SSC0_enEmptyRXBufferInt(void);
INLINE void SSC0_enTXErrInt(void);
INLINE void SSC0_enRXErrInt(void);
INLINE void SSC0_enPhaseErrInt(void);
INLINE void SSC0_enBaudrateErrInt(void);
INLINE void SSC0_disEmptyTXBufferInt(void);
INLINE void SSC0_disEmptyRXBufferInt(void);
INLINE void SSC0_disTXErrInt(void);
INLINE void SSC0_disRXErrInt(void);
INLINE void SSC0_disPhaseErrInt(void);
INLINE void SSC0_disBaudrateErrInt(void);
INLINE uint8 SSC0_getEmptyTXBufferIntSts(void);
INLINE uint8 SSC0_getEmptyRXBufferIntSts(void);
INLINE uint8 SSC0_getTXErrIntSts(void);
INLINE uint8 SSC0_getRXErrIntSts(void);
INLINE uint8 SSC0_getPhaseErrIntSts(void);
INLINE uint8 SSC0_getBaudrateErrIntSts(void);
INLINE void SSC0_clrEmptyTXBufferIntSts(void);
INLINE void SSC0_clrEmptyRXBufferIntSts(void);
INLINE void SSC0_clrTXErrIntSts(void);
INLINE void SSC0_clrRXErrIntSts(void);
INLINE void SSC0_clrPhaseErrIntSts(void);
INLINE void SSC0_clrBaudrateErrIntSts(void);
INLINE uint64 SSC1_getTXvalue(void);
INLINE void SSC1_setTXvalue(uint64 u64_TXvalue);
INLINE uint64 SSC1_getRXvalue(void);
INLINE uint8 SSC1_getBitCnt(void);
INLINE uint8 SSC1_getBusySts(void);
INLINE void SSC1_enEmptyTXBufferInt(void);
INLINE void SSC1_enEmptyRXBufferInt(void);
INLINE void SSC1_enTXErrInt(void);
INLINE void SSC1_enRXErrInt(void);
INLINE void SSC1_enPhaseErrInt(void);
INLINE void SSC1_enBaudrateErrInt(void);
INLINE void SSC1_disEmptyTXBufferInt(void);
INLINE void SSC1_disEmptyRXBufferInt(void);
INLINE void SSC1_disTXErrInt(void);
INLINE void SSC1_disRXErrInt(void);
INLINE void SSC1_disPhaseErrInt(void);
INLINE void SSC1_disBaudrateErrInt(void);
INLINE uint8 SSC1_getEmptyTXBufferIntSts(void);
INLINE uint8 SSC1_getEmptyRXBufferIntSts(void);
INLINE uint8 SSC1_getTXErrIntSts(void);
INLINE uint8 SSC1_getRXErrIntSts(void);
INLINE uint8 SSC1_getPhaseErrIntSts(void);
INLINE uint8 SSC1_getBaudrateErrIntSts(void);
INLINE void SSC1_clrEmptyTXBufferIntSts(void);
INLINE void SSC1_clrEmptyRXBufferIntSts(void);
INLINE void SSC1_clrTXErrIntSts(void);
INLINE void SSC1_clrRXErrIntSts(void);
INLINE void SSC1_clrPhaseErrIntSts(void);
INLINE void SSC1_clrBaudrateErrIntSts(void);

/*******************************************************************************
**                       Deprecated Function Declarations                     **
*******************************************************************************/

/** \brief Set SSC0 Empty TX Buffer Interrupt Node Pointer
 * \warning Do not change this at runtime, use the ConfigWizard to configure this feature!
 */
void SSC0_setEmptyTXBufferIntNodePtr(void) __attribute__((deprecated("Do not change this at runtime, use the ConfigWizard to configure this feature!")));

/** \brief Set SSC0 Empty RX Buffer Interrupt Node Pointer
 * \warning Do not change this at runtime, use the ConfigWizard to configure this feature!
 */
void SSC0_setEmptyRXBufferIntNodePtr(void) __attribute__((deprecated("Do not change this at runtime, use the ConfigWizard to configure this feature!")));

/** \brief Set SSC0 TX Error Interrupt Node Pointer
 * \warning Do not change this at runtime, use the ConfigWizard to configure this feature!
 */
void SSC0_setTXErrIntNodePtr(void) __attribute__((deprecated("Do not change this at runtime, use the ConfigWizard to configure this feature!")));

/** \brief Set SSC0 RX Error Interrupt Node Pointer
 * \warning Do not change this at runtime, use the ConfigWizard to configure this feature!
 */
void SSC0_setRXErrIntNodePtr(void) __attribute__((deprecated("Do not change this at runtime, use the ConfigWizard to configure this feature!")));

/** \brief Set SSC0 Phase Error Interrupt Node Pointer
 * \warning Do not change this at runtime, use the ConfigWizard to configure this feature!
 */
void SSC0_setPhaseErrIntNodePtr(void) __attribute__((deprecated("Do not change this at runtime, use the ConfigWizard to configure this feature!")));

/** \brief Set SSC0 Baudrate Error Interrupt Node Pointer
 * \warning Do not change this at runtime, use the ConfigWizard to configure this feature!
 */
void SSC0_setBaudrateErrIntNodePtr(void) __attribute__((deprecated("Do not change this at runtime, use the ConfigWizard to configure this feature!")));

/** \brief Set SSC1 Empty TX Buffer Interrupt Node Pointer
 * \warning Do not change this at runtime, use the ConfigWizard to configure this feature!
 */
void SSC1_setEmptyTXBufferIntNodePtr(void) __attribute__((deprecated("Do not change this at runtime, use the ConfigWizard to configure this feature!")));

/** \brief Set SSC1 Empty RX Buffer Interrupt Node Pointer
 * \warning Do not change this at runtime, use the ConfigWizard to configure this feature!
 */
void SSC1_setEmptyRXBufferIntNodePtr(void) __attribute__((deprecated("Do not change this at runtime, use the ConfigWizard to configure this feature!")));

/** \brief Set SSC1 TX Error Interrupt Node Pointer
 * \warning Do not change this at runtime, use the ConfigWizard to configure this feature!
 */
void SSC1_setTXErrIntNodePtr(void) __attribute__((deprecated("Do not change this at runtime, use the ConfigWizard to configure this feature!")));

/** \brief Set SSC1 RX Error Interrupt Node Pointer
 * \warning Do not change this at runtime, use the ConfigWizard to configure this feature!
 */
void SSC1_setRXErrIntNodePtr(void) __attribute__((deprecated("Do not change this at runtime, use the ConfigWizard to configure this feature!")));

/** \brief Set SSC1 Phase Error Interrupt Node Pointer
 * \warning Do not change this at runtime, use the ConfigWizard to configure this feature!
 */
void SSC1_setPhaseErrIntNodePtr(void) __attribute__((deprecated("Do not change this at runtime, use the ConfigWizard to configure this feature!")));

/** \brief Set SSC1 Baudrate Error Interrupt Node Pointer
 * \warning Do not change this at runtime, use the ConfigWizard to configure this feature!
 */
void SSC1_setBaudrateErrIntNodePtr(void) __attribute__((deprecated("Do not change this at runtime, use the ConfigWizard to configure this feature!")));

/*******************************************************************************
**                     Global Inline Function Definitions                     **
*******************************************************************************/

/** \brief Get SSC0 Transmit Buffer value
 *
 * \return uint64 Transmit Buffer value
 */
INLINE uint64 SSC0_getTXvalue(void)
{
  uint64 u64_tb1;
  uint64 u64_tb0;
  u64_tb1 = (uint64)SSC0->TB1.reg << 32u;
  u64_tb0 = (uint64)SSC0->TB0.reg;
  return (u64_tb1 | u64_tb0);
}

/** \brief Set SSC0 Transmit Buffer value
 *
 * \param u64_TXvalue Transmit Buffer value
 */
INLINE void SSC0_setTXvalue(uint64 u64_TXvalue)
{
  SSC0->TB1.bit.TB_VALUE_UPPER = (uint32)(u64_TXvalue >> 32u);
  SSC0->TB0.bit.TB_VALUE_LOWER = (uint32)(u64_TXvalue & 0xFFFFFFFFu);
}

/** \brief Get SSC0 Receive Buffer value
 *
 * \return uint64 Receive Buffer value
 */
INLINE uint64 SSC0_getRXvalue(void)
{
  uint64 u64_rb1;
  uint64 u64_rb0;
  u64_rb1 = (uint64)SSC0->RB1.reg << 32u;
  u64_rb0 = (uint64)SSC0->RB0.reg;
  return (u64_rb1 | u64_rb0);
}

/** \brief Get SSC0 Bit Count
 *
 * \return uint8 Bit Count
 */
INLINE uint8 SSC0_getBitCnt(void)
{
  return (uint8)SSC0->STAT.bit.BC;
}

/** \brief Get SSC0 Busy Status
 *
 * \return uint8 Busy Status
 */
INLINE uint8 SSC0_getBusySts(void)
{
  return (uint8)SSC0->STAT.bit.BSY;
}

/** \brief Enable SSC0 Empty Transmit Buffer Interrupt
 */
INLINE void SSC0_enEmptyTXBufferInt(void)
{
  SSC0->IEN.bit.TIREN = 1u;
}

/** \brief Enable SSC0 Empty Receive Buffer Interrupt
 */
INLINE void SSC0_enEmptyRXBufferInt(void)
{
  SSC0->IEN.bit.RIREN = 1u;
}

/** \brief Enable SSC0 Transmit Error Interrupt
 */
INLINE void SSC0_enTXErrInt(void)
{
  SSC0->IEN.bit.TEIREN = 1u;
}

/** \brief Enable SSC0 Receive Error Interrupt
 */
INLINE void SSC0_enRXErrInt(void)
{
  SSC0->IEN.bit.REIREN = 1u;
}

/** \brief Enable SSC0 Phase Error Interrupt
 */
INLINE void SSC0_enPhaseErrInt(void)
{
  SSC0->IEN.bit.PEIREN = 1u;
}

/** \brief Enable SSC0 Baudrate Error Interrupt
 */
INLINE void SSC0_enBaudrateErrInt(void)
{
  SSC0->IEN.bit.BEIREN = 1u;
}

/** \brief Disable SSC0 Empty Transmit Buffer Interrupt
 */
INLINE void SSC0_disEmptyTXBufferInt(void)
{
  SSC0->IEN.bit.TIREN = 0u;
}

/** \brief Disable SSC0 Empty Receive Buffer Interrupt
 */
INLINE void SSC0_disEmptyRXBufferInt(void)
{
  SSC0->IEN.bit.RIREN = 0u;
}

/** \brief Disable SSC0 Transmit Error Interrupt
 */
INLINE void SSC0_disTXErrInt(void)
{
  SSC0->IEN.bit.TEIREN = 0u;
}

/** \brief Disable SSC0 Receive Error Interrupt
 */
INLINE void SSC0_disRXErrInt(void)
{
  SSC0->IEN.bit.REIREN = 0u;
}

/** \brief Disable SSC0 Phase Error Interrupt
 */
INLINE void SSC0_disPhaseErrInt(void)
{
  SSC0->IEN.bit.PEIREN = 0u;
}

/** \brief Disable SSC0 Baudrate Error Interrupt
 */
INLINE void SSC0_disBaudrateErrInt(void)
{
  SSC0->IEN.bit.BEIREN = 0u;
}

/** \brief Get SSC0 Empty Transmit Buffer Interrupt Status SSC0.IS.TIR
 *
 * \return uint8 Empty Transmit Buffer Interrupt Status
 */
INLINE uint8 SSC0_getEmptyTXBufferIntSts(void)
{
  return (uint8)SSC0->IS.bit.TIR;
}

/** \brief Get SSC0 Empty Receive Buffer Interrupt Status SSC0.IS.RIR
 *
 * \return uint8 Empty Receive Buffer Interrupt Status
 */
INLINE uint8 SSC0_getEmptyRXBufferIntSts(void)
{
  return (uint8)SSC0->IS.bit.RIR;
}

/** \brief Get SSC0 Transmit Error Interrupt Status SSC0.IS.TEIR
 *
 * \return uint8 Transmit Error Interrupt Status
 */
INLINE uint8 SSC0_getTXErrIntSts(void)
{
  return (uint8)SSC0->IS.bit.TEIR;
}

/** \brief Get SSC0 Receive Error Interrupt Status SSC0.IS.REIR
 *
 * \return uint8 Receive Error Interrupt Status
 */
INLINE uint8 SSC0_getRXErrIntSts(void)
{
  return (uint8)SSC0->IS.bit.REIR;
}

/** \brief Get SSC0 Phase Error Interrupt Status SSC0.IS.PEIR
 *
 * \return uint8 Phase Error Interrupt Status
 */
INLINE uint8 SSC0_getPhaseErrIntSts(void)
{
  return (uint8)SSC0->IS.bit.PEIR;
}

/** \brief Get SSC0 Baudrate Error Interrupt Status SSC0.IS.BEIR
 *
 * \return uint8 Baudrate Error Interrupt Status
 */
INLINE uint8 SSC0_getBaudrateErrIntSts(void)
{
  return (uint8)SSC0->IS.bit.BEIR;
}

/** \brief Clear SSC0 Empty Transmit Buffer Interrupt Status SSC0.ISC.TIRCLR
 */
INLINE void SSC0_clrEmptyTXBufferIntSts(void)
{
  SSC0->ISC.bit.TIRCLR = 1u;
}

/** \brief Clear SSC0 Empty Receive Buffer Interrupt Status SSC0.ISC.RIRCLR
 */
INLINE void SSC0_clrEmptyRXBufferIntSts(void)
{
  SSC0->ISC.bit.RIRCLR = 1u;
}

/** \brief Clear SSC0 Transmit Error Interrupt Status SSC0.ISC.TEIRCLR
 */
INLINE void SSC0_clrTXErrIntSts(void)
{
  SSC0->ISC.bit.TEIRCLR = 1u;
}

/** \brief Clear SSC0 Receive Error Interrupt Status SSC0.ISC.REIRCLR
 */
INLINE void SSC0_clrRXErrIntSts(void)
{
  SSC0->ISC.bit.REIRCLR = 1u;
}

/** \brief Clear SSC0 Phase Error Interrupt Status SSC0.ISC.PEIRCLR
 */
INLINE void SSC0_clrPhaseErrIntSts(void)
{
  SSC0->ISC.bit.PEIRCLR = 1u;
}

/** \brief Clear SSC0 Baudrate Error Interrupt Status SSC0.ISC.BEIRCLR
 */
INLINE void SSC0_clrBaudrateErrIntSts(void)
{
  SSC0->ISC.bit.BEIRCLR = 1u;
}

/** \brief Get SSC1 Transmit Buffer value
 *
 * \return uint64 Transmit Buffer value
 */
INLINE uint64 SSC1_getTXvalue(void)
{
  uint64 u64_tb1;
  uint64 u64_tb0;
  u64_tb1 = (uint64)SSC1->TB1.reg << 32u;
  u64_tb0 = (uint64)SSC1->TB0.reg;
  return (u64_tb1 | u64_tb0);
}

/** \brief Set SSC1 Transmit Buffer value
 *
 * \param u64_TXvalue Transmit Buffer value
 */
INLINE void SSC1_setTXvalue(uint64 u64_TXvalue)
{
  SSC1->TB1.bit.TB_VALUE_UPPER = (uint32)(u64_TXvalue >> 32u);
  SSC1->TB0.bit.TB_VALUE_LOWER = (uint32)(u64_TXvalue & 0xFFFFFFFFu);
}

/** \brief Get SSC1 Receive Buffer value
 *
 * \return uint64 Receive Buffer value
 */
INLINE uint64 SSC1_getRXvalue(void)
{
  uint64 u64_rb1;
  uint64 u64_rb0;
  u64_rb1 = (uint64)SSC1->RB1.reg << 32u;
  u64_rb0 = (uint64)SSC1->RB0.reg;
  return (u64_rb1 | u64_rb0);
}

/** \brief Get SSC1 Bit Count
 *
 * \return uint8 Bit Count
 */
INLINE uint8 SSC1_getBitCnt(void)
{
  return (uint8)SSC1->STAT.bit.BC;
}

/** \brief Get SSC1 Busy Status
 *
 * \return uint8 Busy Status
 */
INLINE uint8 SSC1_getBusySts(void)
{
  return (uint8)SSC1->STAT.bit.BSY;
}

/** \brief Enable SSC1 Empty Transmit Buffer Interrupt
 */
INLINE void SSC1_enEmptyTXBufferInt(void)
{
  SSC1->IEN.bit.TIREN = 1u;
}

/** \brief Enable SSC1 Empty Receive Buffer Interrupt
 */
INLINE void SSC1_enEmptyRXBufferInt(void)
{
  SSC1->IEN.bit.RIREN = 1u;
}

/** \brief Enable SSC1 Transmit Error Interrupt
 */
INLINE void SSC1_enTXErrInt(void)
{
  SSC1->IEN.bit.TEIREN = 1u;
}

/** \brief Enable SSC1 Receive Error Interrupt
 */
INLINE void SSC1_enRXErrInt(void)
{
  SSC1->IEN.bit.REIREN = 1u;
}

/** \brief Enable SSC1 Phase Error Interrupt
 */
INLINE void SSC1_enPhaseErrInt(void)
{
  SSC1->IEN.bit.PEIREN = 1u;
}

/** \brief Enable SSC1 Baudrate Error Interrupt
 */
INLINE void SSC1_enBaudrateErrInt(void)
{
  SSC1->IEN.bit.BEIREN = 1u;
}

/** \brief Disable SSC1 Empty Transmit Buffer Interrupt
 */
INLINE void SSC1_disEmptyTXBufferInt(void)
{
  SSC1->IEN.bit.TIREN = 0u;
}

/** \brief Disable SSC1 Empty Receive Buffer Interrupt
 */
INLINE void SSC1_disEmptyRXBufferInt(void)
{
  SSC1->IEN.bit.RIREN = 0u;
}

/** \brief Disable SSC1 Transmit Error Interrupt
 */
INLINE void SSC1_disTXErrInt(void)
{
  SSC1->IEN.bit.TEIREN = 0u;
}

/** \brief Disable SSC1 Receive Error Interrupt
 */
INLINE void SSC1_disRXErrInt(void)
{
  SSC1->IEN.bit.REIREN = 0u;
}

/** \brief Disable SSC1 Phase Error Interrupt
 */
INLINE void SSC1_disPhaseErrInt(void)
{
  SSC1->IEN.bit.PEIREN = 0u;
}

/** \brief Disable SSC1 Baudrate Error Interrupt
 */
INLINE void SSC1_disBaudrateErrInt(void)
{
  SSC1->IEN.bit.BEIREN = 0u;
}

/** \brief Get SSC1 Empty Transmit Buffer Interrupt Status SSC1.IS.TIR
 *
 * \return uint8 Empty Transmit Buffer Interrupt Status
 */
INLINE uint8 SSC1_getEmptyTXBufferIntSts(void)
{
  return (uint8)SSC1->IS.bit.TIR;
}

/** \brief Get SSC1 Empty Receive Buffer Interrupt Status SSC1.IS.RIR
 *
 * \return uint8 Empty Receive Buffer Interrupt Status
 */
INLINE uint8 SSC1_getEmptyRXBufferIntSts(void)
{
  return (uint8)SSC1->IS.bit.RIR;
}

/** \brief Get SSC1 Transmit Error Interrupt Status SSC1.IS.TEIR
 *
 * \return uint8 Transmit Error Interrupt Status
 */
INLINE uint8 SSC1_getTXErrIntSts(void)
{
  return (uint8)SSC1->IS.bit.TEIR;
}

/** \brief Get SSC1 Receive Error Interrupt Status SSC1.IS.REIR
 *
 * \return uint8 Receive Error Interrupt Status
 */
INLINE uint8 SSC1_getRXErrIntSts(void)
{
  return (uint8)SSC1->IS.bit.REIR;
}

/** \brief Get SSC1 Phase Error Interrupt Status SSC1.IS.PEIR
 *
 * \return uint8 Phase Error Interrupt Status
 */
INLINE uint8 SSC1_getPhaseErrIntSts(void)
{
  return (uint8)SSC1->IS.bit.PEIR;
}

/** \brief Get SSC1 Baudrate Error Interrupt Status SSC1.IS.BEIR
 *
 * \return uint8 Baudrate Error Interrupt Status
 */
INLINE uint8 SSC1_getBaudrateErrIntSts(void)
{
  return (uint8)SSC1->IS.bit.BEIR;
}

/** \brief Clear SSC1 Empty Transmit Buffer Interrupt Status SSC1.ISC.TIRCLR
 */
INLINE void SSC1_clrEmptyTXBufferIntSts(void)
{
  SSC1->ISC.bit.TIRCLR = 1u;
}

/** \brief Clear SSC1 Empty Receive Buffer Interrupt Status SSC1.ISC.RIRCLR
 */
INLINE void SSC1_clrEmptyRXBufferIntSts(void)
{
  SSC1->ISC.bit.RIRCLR = 1u;
}

/** \brief Clear SSC1 Transmit Error Interrupt Status SSC1.ISC.TEIRCLR
 */
INLINE void SSC1_clrTXErrIntSts(void)
{
  SSC1->ISC.bit.TEIRCLR = 1u;
}

/** \brief Clear SSC1 Receive Error Interrupt Status SSC1.ISC.REIRCLR
 */
INLINE void SSC1_clrRXErrIntSts(void)
{
  SSC1->ISC.bit.REIRCLR = 1u;
}

/** \brief Clear SSC1 Phase Error Interrupt Status SSC1.ISC.PEIRCLR
 */
INLINE void SSC1_clrPhaseErrIntSts(void)
{
  SSC1->ISC.bit.PEIRCLR = 1u;
}

/** \brief Clear SSC1 Baudrate Error Interrupt Status SSC1.ISC.BEIRCLR
 */
INLINE void SSC1_clrBaudrateErrIntSts(void)
{
  SSC1->ISC.bit.BEIRCLR = 1u;
}

/** @}*/

#endif /* _SSC_H */
