/**************************************************************************************************
*                _  _               ___             _                                             *
*               (_)| |__   _ __    / _ \ _ __ ___  | |__    /\  /\                                *
*               | || '_ \ | '__|  / /_\/| '_ ` _ \ | '_ \  / /_/ /                                *
*               | || | | || |    / /_\\ | | | | | || |_) |/ __  /                                 *
*               |_||_| |_||_|    \____/ |_| |_| |_||_.__/ \/ /_/                                  *
*                                                                                                 *
*    ihr GmbH                                                                                     *
*    Airport Boulevard B210                                                                       *
*    77836 Rheinmuenster - Germany                                                                *
*    http://www.ihr.de                                                                            *
*    Phone +49(0) 7229-18475-0                                                                    *
*    Fax   +49(0) 7229-18475-11                                                                   *
***************************************************************************************************
*                                                                                                 *
*       Revision:          $Rev:: 276         $                                                   *
*       Last Modtime:      $Date:: 2022-05-20#$                                                   *
*       Last Modification: $Author:: PhilippKoch                                                $ *
*                                                                                                 *
**************************************************************************************************/
/**
@file         can_types.h
@brief        Type definitions for CAN
*/

#ifndef CAN_TYPES_H
#define CAN_TYPES_H

#include "types.h"
#include "can_cfg.h"
#include "com_types.h"

/* Can/Com API return values and error codes */
#define   E_OK                      (0x00) /* Access successful */
#define   E_NOT_OK                  (0x01) /* invocation of service failed, i.e. parameter error, out of range */
#define   E_NOT_AVAILABLE           (0x80) /* service currently not available (i.e. not initialized, not started) */
#define   E_BUSY                    (0x81) /* a resource is currently in use, i.e. a buffer is locked or full */
#define   E_RX_TIMEOUT              (0x82) /* a timeout occured for the frame while DM is active */
#define   E_RX_LENGTH               (0x83) /* received frame length too long */
#define   E_TX_OVERWRITE            (0x84) /* an unsent transmit message was overwritten */
#define   E_TX_BUFFER_FULL          (0x85) /* a transmit FIFO or queue is full */
#define   E_BUS_PASSIVE             (0x86) /* CAN bus is error-passive */
#define   E_BUS_OFF                 (0x87) /* CAN bus is Bus-Off */


typedef unsigned char   tCanFrameHandle;

typedef enum
{
   StdId         = 0u,
   ExtId         = 1u,
   MixedId       = 2u   /* used in filter settings to allow both types */
} tCanIdType;

typedef struct
{
   uint32                        MsgId;
   uint32                        MsgMask;
   tCanIdType                    IdType;
} tCanFilterDescriptor;

typedef struct
{
   tCanFrameHandle               NObjects;
   tCanFrameHandle               FirstFrmHdl;
   uint8                         Size;
   tCanFilterDescriptor          Filter;
} tCanFifoDescriptor;

typedef struct
{
   tCanFrameHandle               NObjects;
   tCanFrameHandle               FirstFrmHdl;
} tCanFullCanDescriptor;

typedef struct
{
   uint8                         HwNode;
   /* message object handling descriptions */
   tCanFullCanDescriptor         TxFullCanDescr;
   tCanFullCanDescriptor         RxFullCanDescr;
   uint8                         NTxFifos;
   uint8                         NRxFifos;
   tCanFifoDescriptor            TxFifoDescr[N_CAN_TXFIFOS];
   tCanFifoDescriptor            RxFifoDescr[N_CAN_RXFIFOS];

   /* frame handle references */
   tComFrameHandle               FirstTxHdl;
   tComFrameHandle               NTxObjects;
   tComFrameHandle               FirstRxHdl;
   tComFrameHandle               NRxObjects;

   /* Parameters for header bitrate */
   uint8                         SjwQ;
   uint8                         Tseg1Q;
   uint8                         Tseg2Q;
   uint16                        BrDiv;
#if (CAN_SUPPORT_FD == STD_ON)
   /* optional CAN-FD parameters for data bitrate */
   uint8                         FDMode;                   
   uint8                         DSjwQ;
   uint8                         DTseg1Q;
   uint8                         DTseg2Q;
   uint16                        DBrDiv;
#endif
} stCanNodeDescriptor;

extern const stCanNodeDescriptor* Can_GetDesc_CanNodes(void);

#endif /* #ifndef CAN_TYPES_H */
