/**************************************************************************************************
*                _  _               ___             _                                             *
*               (_)| |__   _ __    / _ \ _ __ ___  | |__    /\  /\                                *
*               | || '_ \ | '__|  / /_\/| '_ ` _ \ | '_ \  / /_/ /                                *
*               | || | | || |    / /_\\ | | | | | || |_) |/ __  /                                 *
*               |_||_| |_||_|    \____/ |_| |_| |_||_.__/ \/ /_/                                  *
*                                                                                                 *
*    ihr GmbH                                                                                     *
*    Airport Boulevard B210                                                                       *
*    77836 Rheinmuenster - Germany                                                                *
*    http://www.ihr.de                                                                            *
*    Phone +49(0) 7229-18475-0                                                                    *
*    Fax   +49(0) 7229-18475-11                                                                   *
***************************************************************************************************
*                                                                                                 *
*       Revision:          $Rev:: 250         $                                                   *
*       Last Modtime:      $Date:: 2022-05-19#$                                                   *
*       Last Modification: $Author:: PhilippKoch                                                $ *
*                                                                                                 *
**************************************************************************************************/
/**
@file         com_types.h
@brief        Types of COM component
*/
#ifndef COM_TYPES_H
#define COM_TYPES_H

#include "types.h"
#include "com_cfg.h"

#ifndef STD_ON
#define STD_ON 1
#endif
#ifndef STD_OFF
#define STD_OFF 0
#endif

#ifndef NULL
#define NULL   ((void*)0u)
#endif

#if (CAN_USE_LONG_ID == STD_ON)
typedef uint32    tComFrameId;
#else
typedef uint16    tComFrameId;
#endif


typedef uint16    tComFrameHandle;
typedef uint16    tComSignalHandle;

/* CalloutFunc for Tx frames is the TxConfirmation(TxHandle, State) */
/* CalloutFunc for Rx frames is the RxIndication(RxHandle, RxLength) */
typedef void (*tFrmCalloutFunc)(tComFrameHandle, uint8);
/* ErrorFunc is the ErrorNotification(Handle, ErrorCode) */
typedef void (*tFrmErrorFunc)(tComFrameHandle, uint8);
typedef uint8 (*tSignalPackFunc)(tComSignalHandle, void*);

typedef struct
{
   tComFrameHandle  Handle;
   tComFrameId      Id;
   uint8            BufferSize;
   uint8            Flags;
   uint8            Channel;
   uint8*           pBuffer;
   uint8*           pShadow;
   const uint8*     pInitData;
   tFrmCalloutFunc  CalloutFunc;
   tFrmErrorFunc    ErrorFunc;
   uint16           FirstSignal;
   uint16           NSignals;
   uint16           CycleTO;
} stComFrameDescriptor;

typedef struct
{
   tComSignalHandle Handle;
   tComFrameHandle  Owner;
   uint16           BitPos;
   uint16           BitSize;
   uint8            Format;
} stComSignalDescriptor;

extern const stComFrameDescriptor*  COM_GetPtr_TxFrmDescrStart(void);
extern const stComFrameDescriptor*  COM_GetPtr_RxFrmDescrStart(void);
extern const stComSignalDescriptor* COM_GetPtr_TxSignalsStart(void);
extern const stComSignalDescriptor* COM_GetPtr_RxSignalsStart(void);

/* Evaluation of stComFrameDescriptor.Flags */
#define FLAGS_ENABLE_IRQ   0x80u
#define FLAGS_RESERVED_6   0x40u
#define FLAGS_MASK_HW_MODE 0x30u
#define FLAGS_FD_FRAME     0x08u
#define FLAGS_USE_BRS      0x04u
#define FLAGS_EXT_ID       0x02u
#define FLAGS_REMOTE_FRAME 0x01u

/* Evaluation of stComSignalDescriptor[].Format */
#define FORMAT_RESERVED_7        0x80u
#define FORMAT_RESERVED_6        0x40u
#define FORMAT_IS_SIGNED         0x20u
#define FORMAT_IS_SINGLE_FLAG    0x10u
#define FORMAT_IS_ALIGNED        0x08u
#define FORMAT_IS_BIG_ENDIAN     0x04u
#define FORMAT_MASK_BASE_TYPE    0x03u

/* Evaluation of format base type field */
#define FORMAT_BASE_TYPE_8BIT    0x00u
#define FORMAT_BASE_TYPE_16BIT   0x01u
#define FORMAT_BASE_TYPE_32BIT   0x02u
#define FORMAT_BASE_TYPE_64BIT   0x03u

#endif /* #ifndef COM_TYPES_H */
