/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/**
 * \file     main.c
 *
 * \brief    Template for main.c
 *
 * \version  V1.5.5
 * \date     11. Nov 2021
 *
 * \note
 */

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** DM           Daniel Mysliwitz                                              **
** BG           Blandine Guillot                                              **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.5.0: 2015-08-07, BG:   Initial version for TLE989x                      **
** V1.5.1: 2020-12-18, BG:   EP-652: Corrected name of error code variable    **
**                           clear Watchdog fail status                       **
**                           clear fail safe status flags                     **
**                           clear bridge driver status flags                 **
** V1.5.2: 2021-02-03, JO:   EP-684: Fixed MISRA violations in main.c file    **
** V1.5.3: 2021-03-08, BG:   EP-733: Updated comments                         **
**                           Removed FIFO pull-up enable to put it in PMU_init**
** V1.5.4: 2021-07-27, BG:   EP-814: Added return code for TLE_init()         **
**                           Removed clearing of status registers, should be  **
**                           done in the init functions if they are passed    **
** V1.5.5: 2021-11-11, JO:   EP-937: Updated copyright and branding           **
*******************************************************************************/

/*******************************************************************************
**                                  Includes                                  **
*******************************************************************************/
#include "tle_device.h"
#include "types.h"

/*******************************************************************************
**                        Global Constant Declarations                        **
*******************************************************************************/

/*******************************************************************************
**                          Global Type Declarations                          **
*******************************************************************************/

/*******************************************************************************
**                          Global Macro Declarations                         **
*******************************************************************************/

/*******************************************************************************
**                        Global Function Declarations                        **
*******************************************************************************/

/*******************************************************************************
**                     Global Inline Function Definitions                     **
*******************************************************************************/

sint32 main(void)
{
  sint8 s8_returnCode;
  /* Clear watchdog fail status */
  PMU_clrFailSafeWatchdogFailSts();
  /* Initialization of hardware modules based on Config Wizard configuration */
  s8_returnCode = TLE_init();

  if (s8_returnCode != ERR_LOG_SUCCESS)
  {
    /* Place your code here to handle an initialization error */
  }

  /*****************************************************************************
  ** Place your application code here                                         **
  *****************************************************************************/

  /*****************************************************************************
  ** Main endless loop                                                        **
  *****************************************************************************/
  for (;;)
  {
    /* Main watchdog service */
    (void)PMU_serviceFailSafeWatchdog();
    /***************************************************************************
    ** Place your application code here                                       **
    ***************************************************************************/
  }
}

